/* This file is part of turtle, a turtle-graphics system for Scheme.

Copyright (C) 2008  Luca Saiu

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */


#ifndef TURTLE_DEBUG_H_
#define TURTLE_DEBUG_H_

#include <stdarg.h>
#include <stdlib.h>
#include <unistd.h>

/* Write a fatal error message to stdout and exit. The format
   string is used exactly like in printf():  */
void turtle_fatal(const char *error_message_template, ...)
  __attribute__((noreturn));

/* Safe versions of malloc() and friends which call turtle_fatal()
   in case of error, so that you don't have to check for failures
   yourself: */
void* turtle_malloc(const size_t size_in_bytes)
  __attribute__((malloc));
void* turtle_realloc(void *buffer, const size_t size_in_bytes)
  __attribute__((malloc));
void turtle_free(void *buffer); // just for uniformity

#endif // #ifndef TURTLE_DEBUG_H_
